Name:          jctools
Version:       3.1.0
Release:       %mkrel 1
Group:         Development/Java
Summary:       Java Concurrency Tools for the JVM
License:       ASL 2.0
URL:           http://jctools.github.io/JCTools/
Source0:       https://github.com/JCTools/JCTools/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  maven-local
BuildRequires:  mvn(com.github.javaparser:javaparser-core) >= 3.14.16
BuildRequires:  mvn(com.google.guava:guava-testlib)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-all)

BuildArch:     noarch

# Parent pom package obsoleted in F34
Obsoletes: %{name}-parent < 3.1.0-1
# Can't ship these modules any longer due to usage of Unsafe.defineClass
# not available in JDK 11, see https://github.com/JCTools/JCTools/issues/254
Obsoletes: %{name}-channels < 3.1.0-1
Obsoletes: %{name}-experimental < 3.1.0-1

%description
This project aims to offer some concurrent data structures
currently missing from the JDK:

* SPSC/MPSC/SPMC/MPMC Bounded lock free queues
* SPSC/MPSC Unbounded lock free queues
* Alternative interfaces for queues
* Offheap concurrent ring buffer for ITC/IPC purposes
* Single Writer Map/Set implementations
* Low contention stats counters
* Executor

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n JCTools-%{version}

# Cleanup
find . -name '*.class' -print -delete
find . -name '*.jar' -print -delete

# Remove failure-prone tests (race condition?)
rm jctools-core/src/test/java/org/jctools/queues/MpqSanityTestMpscCompound.java
rm jctools-core/src/test/java/org/jctools/queues/atomic/AtomicMpqSanityTestMpscCompound.java
rm jctools-core/src/test/java/org/jctools/maps/NonBlockingHashMapTest.java

# Fix up version
%pom_xpath_set pom:project/pom:version %{version}
%pom_xpath_set -r pom:parent/pom:version %{version} %{name}-{build,core,channels,experimental}

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :coveralls-maven-plugin %{name}-core
%pom_remove_plugin :jacoco-maven-plugin %{name}-core
%pom_remove_plugin :maven-source-plugin %{name}-core
%pom_remove_plugin :maven-javadoc-plugin %{name}-core

# Unavailable deps
%pom_disable_module %{name}-benchmarks
%pom_disable_module %{name}-concurrency-test

# Can't build these modules due to use of Unsafe.defineClass which is not present
# in JDK 11, see https://github.com/JCTools/JCTools/issues/254
%pom_disable_module %{name}-channels
%pom_disable_module %{name}-experimental

# No need to package internal build tools
%mvn_package :jctools-parent __noinstall
%mvn_package :jctools-build __noinstall

%build
%mvn_build -f -s

%install
%mvn_install

%files -f .mfiles-%{name}-core
%doc README.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Mon Sep 07 2020 daviddavid <daviddavid> 3.1.0-1.mga8
+ Revision: 1623163
- Update to latest upstream version 3.1.0
- Obsolete sub-packages that cannot be built on JDK 11
- Patch for javaparser API changes

* Sun Feb 16 2020 umeabot <umeabot> 2.1.2-4.mga8
+ Revision: 1536149
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 2.1.2-3.mga8
+ Revision: 1453403
- Disable failure-prone unreliable test

* Thu Jul 18 2019 daviddavid <daviddavid> 2.1.2-2.mga8
+ Revision: 1422562
- fix UTF-8 characters in description

* Thu Jul 18 2019 daviddavid <daviddavid> 2.1.2-1.mga8
+ Revision: 1422384
- Update to latest upstream release 2.1.2

* Thu Sep 20 2018 umeabot <umeabot> 2.0.2-2.mga7
+ Revision: 1278918
- Mageia 7 Mass Rebuild

* Tue Aug 15 2017 daviddavid <daviddavid> 2.0.2-1.mga7
+ Revision: 1140713
- Update to 2.0.2

* Fri Aug 11 2017 daviddavid <daviddavid> 1.2.1-1.mga7
+ Revision: 1139820
- update to 1.2.1 (sync with fedora 27)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.1-0.3.alpha.1.mga6
+ Revision: 977112
- sync package jctools with fedora
- imported package jctools


* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-0.3.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-0.2.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 19 2015 gil cattaneo <puntogil@libero.it> 1.1-0.1.alpha
- initial rpm
